
import { useState, useEffect } from 'react';
import { useNavigate } from 'react-router-dom';
import { useAuth } from '@/contexts/AuthContext';
import { InputOTP, InputOTPGroup, InputOTPSlot } from '@/components/ui/input-otp';
import { Button } from '@/components/ui/button';
import { ArrowRight, Loader2, RefreshCcw } from 'lucide-react';
import { toast } from 'sonner';
import Navbar from '@/components/Navbar';

const VerifyOTP = () => {
  const navigate = useNavigate();
  const { login, verificationMethod, verificationValue } = useAuth();
  const [otp, setOtp] = useState('');
  const [isLoading, setIsLoading] = useState(false);
  const [remainingTime, setRemainingTime] = useState(60);

  useEffect(() => {
    // Redirect if there's no verification in progress
    if (!verificationMethod || !verificationValue) {
      navigate('/signin');
      return;
    }

    // Set up timer
    const timer = setInterval(() => {
      setRemainingTime((prev) => {
        if (prev <= 1) {
          clearInterval(timer);
          return 0;
        }
        return prev - 1;
      });
    }, 1000);

    return () => clearInterval(timer);
  }, [verificationMethod, verificationValue, navigate]);

  const handleResendCode = () => {
    setRemainingTime(60);
    toast.success("Code resent", {
      description: `A new verification code has been sent to your ${verificationMethod}.`,
    });
  };

  const handleSubmit = async (e) => {
    e.preventDefault();
    
    if (otp.length !== 6) {
      toast.error("Invalid code", {
        description: "Please enter a valid 6-digit verification code.",
      });
      return;
    }

    setIsLoading(true);
    
    try {
      // For Supabase, we actually need to use the real login after OTP validation
      // Since we're simulating this in our app for now, we'll just navigate
      // In a real implementation, this would call supabase.auth.verifyOtp
      
      // Simulate API call delay
      await new Promise(resolve => setTimeout(resolve, 1500));
      
      // In a real implementation with Supabase, we would do:
      // await login(verificationValue, 'password'); 
      // But for now we'll just navigate
      
      toast.success("Verification successful!", {
        description: "You are now signed in.",
      });
      
      navigate('/assessment');
    } catch (error) {
      toast.error("Verification failed", {
        description: "Please try again.",
      });
    } finally {
      setIsLoading(false);
    }
  };

  return (
    <div className="min-h-screen bg-gradient-to-b from-white to-gray-50">
      <Navbar />
      
      <div className="pt-32 pb-16">
        <div className="container max-w-md mx-auto px-4">
          <div className="glass-panel p-8 animate-fade-up">
            <h1 className="text-2xl font-bold text-center mb-2">Verify Your {verificationMethod === 'email' ? 'Email' : 'Phone'}</h1>
            <p className="text-center text-muted-foreground mb-6">
              We've sent a verification code to {verificationMethod === 'email' ? 'your email' : 'your phone'}
              <br />
              <span className="font-medium">{verificationValue}</span>
            </p>
            
            <form onSubmit={handleSubmit} className="space-y-6">
              <div className="flex justify-center">
                <InputOTP
                  maxLength={6}
                  value={otp}
                  onChange={setOtp}
                  render={({ slots }) => (
                    <InputOTPGroup>
                      {slots.map((slot, index) => (
                        <InputOTPSlot key={index} {...slot} index={index} />
                      ))}
                    </InputOTPGroup>
                  )}
                />
              </div>
              
              <Button 
                type="submit" 
                className="w-full"
                disabled={isLoading || otp.length !== 6}
              >
                {isLoading ? (
                  <>
                    <Loader2 className="mr-2 h-4 w-4 animate-spin" />
                    Verifying
                  </>
                ) : (
                  <>
                    Verify
                    <ArrowRight size={16} className="ml-2" />
                  </>
                )}
              </Button>
            </form>
            
            <div className="mt-6 text-center">
              <p className="text-sm text-muted-foreground mb-2">
                Didn't receive a code? {remainingTime > 0 ? `Resend in ${remainingTime}s` : ''}
              </p>
              {remainingTime === 0 && (
                <Button 
                  variant="outline" 
                  onClick={handleResendCode} 
                  className="text-xs h-8"
                >
                  <RefreshCcw size={14} className="mr-1" />
                  Resend Code
                </Button>
              )}
            </div>
          </div>
        </div>
      </div>
    </div>
  );
};

export default VerifyOTP;
